Crate git_cliff_core

Crate git_cliff_core 

A highly customizable changelog generator ⛰️

The crate provides a set of optional features that can be enabled in your Cargo.toml file.

Features

  • repo (enabled by default) — Enable parsing commits from a git repository. You can turn this off if you already have the commits to put in the changelog and you don’t need git-cliff to parse them.
  • github — Enable integration with GitHub. You can turn this off if you don’t use GitHub and don’t want to make network requests to the GitHub API.
  • gitlab — Enable integration with GitLab. You can turn this off if you don’t use GitLab and don’t want to make network requests to the GitLab API.
  • bitbucket — Enable integration with Bitbucket. You can turn this off if you don’t use Bitbucket and don’t want to make network requests to the Bitbucket API.
  • gitea — Enable integration with Gitea. You can turn this off if you don’t use Gitea and don’t want to make network requests to the Gitea API.
  • azure_devops — Enable integration with Azure DevOps. You can turn this off if you don’t use Azure DevOps and don’t want to make network requests to the Azure DevOps API.
  • tracing — Enable tracing instrumentation in git-cliff-core. This is intentionally feature-gated to keep the core library lightweight and to allow downstream users to opt in to tracing.
  • tracing-indicatif — Enable integration with tracing-indicatif. This adds progress reporting for tracing spans using indicatif. You can turn this off if you don’t need progress output.

Modules

changelog
Changelog generator.
command
Command runner.
commit
Git commit.
config
Config file parser.
contributor
Remote contributor.
embed
Embedded file handler.
error
Error handling.
process
Commit processing pipeline.
release
Common release type.
remoteremote
Remote handler.
reporepo
Git repository.
statistics
Release statistics.
summary
Changelog commit processing summary.
tag
Git tag.
template
Template engine.

Constants

CONFIG_FILES
List of possible configuration file location.
DEFAULT_CONFIG
Default configuration file.
DEFAULT_OUTPUT
Default output file.
IGNORE_FILE
Default ignore file.