pub enum ProcessingStep {
CommitPreprocessors,
SplitCommits,
ConventionalCommits,
CommitParsers,
LinkParsers,
}Expand description
Processing steps for commits.
Variants
CommitPreprocessors
An array of regex based parsers to modify commit messages prior to further processing.
SplitCommits
Split commits on newlines, treating each line as an individual commit.
ConventionalCommits
Parse commits according to the conventional commits specification.
CommitParsers
An array of regex based parsers for extracting data from the commit message.
LinkParsers
An array of regex based parsers to extract links from the commit message and add them to the commit’s context.