pub struct GitConfig {Show 23 fields
pub processing_order: Option<Vec<ProcessingStep>>,
pub conventional_commits: bool,
pub require_conventional: bool,
pub filter_unconventional: bool,
pub split_commits: bool,
pub commit_preprocessors: Vec<TextProcessor>,
pub commit_parsers: Vec<CommitParser>,
pub protect_breaking_commits: bool,
pub link_parsers: Vec<LinkParser>,
pub filter_commits: bool,
pub fail_on_unmatched_commit: bool,
pub tag_pattern: Option<Regex>,
pub skip_tags: Option<Regex>,
pub ignore_tags: Option<Regex>,
pub count_tags: Option<Regex>,
pub use_branch_tags: bool,
pub topo_order: bool,
pub topo_order_commits: bool,
pub sort_commits: String,
pub limit_commits: Option<usize>,
pub recurse_submodules: Option<bool>,
pub include_paths: Vec<Pattern>,
pub exclude_paths: Vec<Pattern>,
}Expand description
Git configuration
Fields
processing_order: Option<Vec<ProcessingStep>>Optional processing order for commit transformation steps.
If unset, the legacy processing behavior is preserved for backwards compatibility.
conventional_commits: boolParse commits according to the conventional commits specification.
require_conventional: boolRequire all commits to be conventional.
Takes precedence over filter_unconventional.
filter_unconventional: boolExclude commits that do not match the conventional commits specification from the changelog.
split_commits: boolSplit commits on newlines, treating each line as an individual commit.
commit_preprocessors: Vec<TextProcessor>An array of regex based parsers to modify commit messages prior to further processing.
commit_parsers: Vec<CommitParser>An array of regex based parsers for extracting data from the commit message.
protect_breaking_commits: boolPrevent commits having the BREAKING CHANGE: footer from being excluded
by commit parsers.
link_parsers: Vec<LinkParser>An array of regex based parsers to extract links from the commit message and add them to the commit’s context.
filter_commits: boolExclude commits that are not matched by any commit parser.
fail_on_unmatched_commit: boolFail on a commit that is not matched by any commit parser.
tag_pattern: Option<Regex>Regex to select git tags that represent releases.
Regex to select git tags that do not represent proper releases.
Regex to exclude git tags after applying the tag_pattern.
Regex to count matched tags.
Include only the tags that belong to the current branch.
topo_order: boolOrder releases topologically instead of chronologically.
topo_order_commits: boolOrder commits chronologically instead of topologically.
sort_commits: StringHow to order commits in each group/release within the changelog.
limit_commits: Option<usize>Limit the total number of commits included in the changelog.
recurse_submodules: Option<bool>Read submodule commits.
include_paths: Vec<Pattern>Include related commits with changes at the specified paths.
exclude_paths: Vec<Pattern>Exclude unrelated commits with changes at the specified paths.