Module summary

Module summary 

Changelog commit processing summary.

Structs

Summary
Aggregated summary of commit processing results for a changelog.

Enums

CommitProcessingErrorKind
Represents the category of errors that may occur while processing a commit.