#[non_exhaustive]pub enum CommitProcessingErrorKind {
Io,
Parse,
Json,
Field,
Group,
Skipped,
Other,
}Expand description
Represents the category of errors that may occur while processing a commit.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
Occurs while spawning or interacting with an OS command via a preprocessor.
Parse
Occurs when parsing a commit message into a conventional commit fails.
Json
Occurs when serializing or deserializing data to or from JSON fails.
Field
Occurs when a referenced commit field is missing or has an unsupported type.
Group
Occurs when a commit does not match any grouping rule.
Skipped
Occurs when a commit is skipped intentionally due to configuration.
Other
Occurs when an error does not fit into any other defined category.
Implementations
Sourceimpl CommitProcessingErrorKind
impl CommitProcessingErrorKind
Sourcepub fn should_warn(self) -> bool
pub fn should_warn(self) -> bool
Whether this error kind should be surfaced as a warning summary.