pub struct Bump {
pub features_always_bump_minor: Option<bool>,
pub breaking_always_bump_major: Option<bool>,
pub initial_tag: Option<String>,
pub custom_major_increment_regex: Option<String>,
pub custom_minor_increment_regex: Option<String>,
pub bump_type: Option<BumpType>,
}Expand description
Bump version configuration.
Fields
features_always_bump_minor: Option<bool>Configures automatic minor version increments for feature changes.
When true, a feature will always trigger a minor version update.
When false, a feature will trigger:
- A patch version update if the major version is 0.
- A minor version update otherwise.
breaking_always_bump_major: Option<bool>Configures 0 -> 1 major version increments for breaking changes.
When true, a breaking change commit will always trigger a major
version update (including the transition from version 0 to 1)
When false, a breaking change commit will trigger:
- A minor version update if the major version is 0.
- A major version update otherwise.
initial_tag: Option<String>Configures the initial version of the project.
When set, the version will be set to this value if no tags are found.
custom_major_increment_regex: Option<String>Configure a custom regex pattern for major version increments.
This will check only the type of the commit against the given pattern.
Note
commit type according to the spec is only [a-zA-Z]+
custom_minor_increment_regex: Option<String>Configure a custom regex pattern for minor version increments.
This will check only the type of the commit against the given pattern.
Note
commit type according to the spec is only [a-zA-Z]+
bump_type: Option<BumpType>Force to always bump in major, minor or patch.
Implementations