Changelog commit processing summary.
Structs
- Summary
- Aggregated summary of commit processing results for a changelog.
Enums
- Commit
Processing Error Kind - Represents the category of errors that may occur while processing a commit.
Changelog commit processing summary.